@@ -31,6 +31,8 @@
 #include <gtk/gtk.h>
 #include <gtk/gtkx.h>
 
+#include <gdesktop-enums.h>
+
 #include "gs-window.h"
 #include "gs-marshal.h"
 #include "subprocs.h"
@@ -115,6 +117,9 @@ struct GSWindowPrivate
 
         GTimer    *timer;
 
+        GSettings           *clock_settings;
+        GDesktopClockFormat  clock_format;
+
 #ifdef HAVE_SHAPE_EXT
         int        shape_event_base;
 #endif
@@ -261,6 +266,9 @@ clear_widget (GtkWidget *widget)
 {
         GdkColor color = { 0, 0x0000, 0x0000, 0x0000 };
 
+        if (!gtk_widget_get_realized (widget))
+                return;
+
         gdk_window_set_background (gtk_widget_get_window (widget),
                                    &color);
         gtk_widget_queue_draw (GTK_WIDGET (widget));
@@ -431,111 +439,9 @@ spawn_make_environment_for_screen (GdkScreen  *screen,
         return retval;
 }
 
-static gboolean
-spawn_command_line_on_screen_sync (GdkScreen    *screen,
-                                   const gchar  *command_line,
-                                   char        **standard_output,
-                                   char        **standard_error,
-                                   int          *exit_status,
-                                   GError      **error)
-{
-        char     **argv = NULL;
-        char     **envp = NULL;
-        gboolean   retval;
-
-        g_return_val_if_fail (command_line != NULL, FALSE);
-
-        if (! g_shell_parse_argv (command_line, NULL, &argv, error)) {
-                return FALSE;
-        }
-
-        envp = spawn_make_environment_for_screen (screen, NULL);
-
-        retval = g_spawn_sync (NULL,
-                               argv,
-                               envp,
-                               G_SPAWN_SEARCH_PATH,
-                               NULL,
-                               NULL,
-                               standard_output,
-                               standard_error,
-                               exit_status,
-                               error);
-
-        g_strfreev (argv);
-        g_strfreev (envp);
-
-        return retval;
-}
-
-static GdkVisual *
-get_best_visual_for_screen (GdkScreen *screen)
-{
-        char         *command;
-        char         *std_output;
-        int           exit_status;
-        GError       *error;
-        unsigned long v;
-        char          c;
-        GdkVisual    *visual;
-        gboolean      res;
-
-        visual = NULL;
-
-        command = g_build_filename (LIBEXECDIR, "gnome-screensaver-gl-helper", NULL);
-
-        error = NULL;
-        std_output = NULL;
-        res = spawn_command_line_on_screen_sync (screen,
-                                                 command,
-                                                 &std_output,
-                                                 NULL,
-                                                 &exit_status,
-                                                 &error);
-        if (! res) {
-                gs_debug ("Could not run command '%s': %s", command, error->message);
-                g_error_free (error);
-                goto out;
-        }
-
-        if (1 == sscanf (std_output, "0x%lx %c", &v, &c)) {
-                if (v != 0) {
-                        VisualID      visual_id;
-
-                        visual_id = (VisualID) v;
-                        visual = gdk_x11_screen_lookup_visual (screen, visual_id);
-
-                        gs_debug ("Found best GL visual for screen %d: 0x%x",
-                                  gdk_screen_get_number (screen),
-                                  (unsigned int) visual_id);
-                }
-        }
- out:
-        g_free (std_output);
-        g_free (command);
-
-        return g_object_ref (visual);
-}
-
-static void
-widget_set_best_visual (GtkWidget *widget)
-{
-        GdkVisual *visual;
-
-        g_return_if_fail (widget != NULL);
-
-        visual = get_best_visual_for_screen (gtk_widget_get_screen (widget));
-        if (visual != NULL) {
-                gtk_widget_set_visual (widget, visual);
-                g_object_unref (visual);
-        }
-}
-
 static void
 gs_window_real_realize (GtkWidget *widget)
 {
-        widget_set_best_visual (widget);
-
         if (GTK_WIDGET_CLASS (gs_window_parent_class)->realize) {
                 GTK_WIDGET_CLASS (gs_window_parent_class)->realize (widget);
         }
@@ -1646,9 +1552,9 @@ void
 gs_window_cancel_unlock_request (GSWindow  *window)
 {
         /* FIXME: This is a bit of a hammer approach...
-	 * Maybe we should send a delete-event to
-	 * the plug?
-	 */
+         * Maybe we should send a delete-event to
+         * the plug?
+         */
         g_return_if_fail (GS_IS_WINDOW (window));
 
         popdown_dialog (window);
@@ -2117,11 +2023,11 @@ gs_window_real_get_preferred_width (GtkWidget *widget,
                                gint      *minimal_width,
                                gint      *natural_width)
 {
-	GtkRequisition requisition;
+        GtkRequisition requisition;
 
-	gs_window_real_size_request (widget, &requisition);
+        gs_window_real_size_request (widget, &requisition);
 
-	*minimal_width = *natural_width = requisition.width;
+        *minimal_width = *natural_width = requisition.width;
 }
 
 static void
@@ -2129,11 +2035,11 @@ gs_window_real_get_preferred_height (GtkWidget *widget,
                                 gint      *minimal_height,
                                 gint      *natural_height)
 {
-	GtkRequisition requisition;
+        GtkRequisition requisition;
 
-	gs_window_real_size_request (widget, &requisition);
+        gs_window_real_size_request (widget, &requisition);
 
-	*minimal_height = *natural_height = requisition.height;
+        *minimal_height = *natural_height = requisition.height;
 }
 
 static void
@@ -2285,19 +2191,17 @@ update_clock (GSWindow *window)
         const char *clock_format;
         char *text;
         char *markup;
-        gboolean use_24 = FALSE;
         GDateTime *dt;
 
         /* clock */
-        /* FIXME: set 12/24 hour */
-        if (use_24)
+        if (window->priv->clock_format == G_DESKTOP_CLOCK_FORMAT_24H)
                 clock_format = _("%a %R");
         else
                 clock_format = _("%a %l:%M %p");
 
         dt = g_date_time_new_now_local ();
         text = g_date_time_format (dt, clock_format);
-        markup = g_strdup_printf ("<b><span foreground=\"white\">%s</span></b>", text);
+        markup = g_strdup_printf ("<b><span foreground=\"#ccc\">%s</span></b>", text);
         gtk_label_set_markup (GTK_LABEL (window->priv->clock), markup);
         g_free (markup);
         g_free (text);
@@ -2355,7 +2259,7 @@ update_name_label (GSWindow *window)
         char *name;
         char *markup;
         name = get_user_display_name ();
-        markup = g_strdup_printf ("<b><span foreground=\"white\">%s</span></b>", name);
+        markup = g_strdup_printf ("<b><span foreground=\"#ccc\">%s</span></b>", name);
         gtk_label_set_markup (GTK_LABEL (window->priv->name_label), markup);
         g_free (markup);
         g_free (name);
@@ -2380,9 +2284,9 @@ create_panel (GSWindow *window)
         bg.blue = 0;
         bg.alpha = 1.0;
 
-        fg.red = 1.0;
-        fg.green = 1.0;
-        fg.blue = 1.0;
+        fg.red = 0.8;
+        fg.green = 0.8;
+        fg.blue = 0.8;
         fg.alpha = 1.0;
 
         all_states = 0;
@@ -2429,6 +2333,20 @@ create_panel (GSWindow *window)
         gtk_widget_show_all (window->priv->panel);
 }
 
+static void
+update_clock_format (GSettings  *settings,
+                     const char *key,
+                     GSWindow   *window)
+{
+        GDesktopClockFormat clock_format;
+
+        clock_format = g_settings_get_enum (settings, key);
+        if (clock_format != window->priv->clock_format) {
+                window->priv->clock_format = clock_format;
+                queue_clock_update (window);
+        }
+}
+
 static void
 gs_window_init (GSWindow *window)
 {
@@ -2478,6 +2396,11 @@ gs_window_init (GSWindow *window)
         gtk_box_pack_start (GTK_BOX (window->priv->vbox), window->priv->drawing_area, TRUE, TRUE, 0);
         create_info_bar (window);
 
+        window->priv->clock_settings = g_settings_new ("org.gnome.desktop.interface");
+        window->priv->clock_format = g_settings_get_enum (window->priv->clock_settings, "clock-format");
+        g_signal_connect (window->priv->clock_settings, "changed::clock-format",
+                          G_CALLBACK (update_clock_format), window);
+
         force_no_pixmap_background (window->priv->drawing_area);
 }
 
@@ -2509,6 +2432,10 @@ gs_window_finalize (GObject *object)
         g_free (window->priv->logout_command);
         g_free (window->priv->keyboard_command);
 
+        if (window->priv->clock_settings) {
+                g_object_unref (window->priv->clock_settings);
+        }
+
         if (window->priv->clock_update_id > 0) {
                 g_source_remove (window->priv->clock_update_id);
         }
